@@ -67,11 +67,11 @@ class NativeHWManagementService(Service):
     def hw_management_service_set_logging_endpoint(self, param_dict, **kwargs):
         return self._grpc_helper(self.stub.SetLoggingEndpoint, hw_management_service_pb2.SetLoggingEndpointRequest, param_dict, **kwargs)
 
-    # rpc GetLoggingEndpoint(HardwareID) returns(GetLoggingEndpointResponse);
+    # rpc GetLoggingEndpoint(Uuid) returns(GetLoggingEndpointResponse);
     @keyword
     @is_connected
     def hw_management_service_get_logging_endpoint(self, param_dict, **kwargs):
-        return self._grpc_helper(self.stub.GetLoggingEndpoint, hw_pb2.HardwareID, param_dict)
+        return self._grpc_helper(self.stub.GetLoggingEndpoint, hw_pb2.Uuid, param_dict)
 
     # rpc SetMsgBusEndpoint(SetMsgBusEndpointRequest) returns(SetRemoteEndpointResponse);
     @keyword
